# History

## 0.3.13 (2023-09-05)

* Documentation improvements.

## 0.3.12 (2023-08-29)

* Minor fixes to the documentation and examples.

## 0.3.11 (2023-08-28)

* Minor fixes missed in 0.3.10 release.

## 0.3.10 (2023-08-28)

* Minor fixes missed in 0.3.9 release.

## 0.3.9 (2023-08-28)

* Minor fixes missed in 0.3.8 release.

## 0.3.8 (2023-08-28)

* Add cmake build.
* Support for Python 3.7, 3.8, 3.9, 3.10, 3.11.
* Remove mention of Python 2.

## 0.3.7 (2021-12-18)

* Fix build on GCC (Issue #8).

## 0.3.6 (2021-12-18)

* Add documentation on NaN in rolling median.
* Add plots using shared_memory.
* Add Python 3.10 support.

## 0.3.5 (2021-05-02)

* Fix uncaught exception when trying to remove a NaN.

## 0.3.4 (2021-04-28)

* Improve documentation mainly around multiprocessing.shared_memory and tests.

## 0.3.3 (2021-03-25)

* Add Python benchmarks, fix some build issues.

## 0.3.2 (2021-03-18)

* Fix lambda issues with Python 3.8, 3.9.

## 0.3.1 (2021-03-17)

* Support Python 3.7, 3.8, 3.9.

## 0.3.0 (2017-08-18)

* Public release.
* Allows storing of ``PyObject*`` and rich comparison.

## 0.2.0

Python module now named ``orderedstructs``.

# 0.1.0

Initial release.

